Documentation
¶
Overview ¶
SPDX-FileCopyrightText: 2026 Outscale SAS <opensource@outscale.com>
SPDX-License-Identifier: BSD-3-Clause
Index ¶
Constants ¶
This section is empty.
Variables ¶
var GhURL = "https://api.github.com/repos/outscale/octl/releases/latest"
Functions ¶
func FindAndCheckAssetDigest ¶ added in v0.0.18
func FindAndCheckAssetDigest(a ReleaseAsset, cs map[string]string) (string, error)
func LatestRelease ¶
Types ¶
type ReleaseAsset ¶ added in v0.0.15
type ReleaseAsset struct {
Name string `json:"name,omitempty"`
BrowserDownloadURL string `json:"browser_download_url,omitempty"`
Digest string `json:"digest,omitempty"`
}
ReleaseAsset represents a GitHub release asset in a repository.
type RepositoryRelease ¶ added in v0.0.15
type RepositoryRelease struct {
TagName string `json:"tag_name,omitempty"`
Body string `json:"body,omitempty"`
Assets []ReleaseAsset `json:"assets,omitempty"`
}
RepositoryRelease represents a GitHub release in a repository.
type UpdateOption ¶ added in v0.0.17
type UpdateOption func(*UpdatePolicy)
func WithDryRun ¶ added in v0.0.18
func WithDryRun() UpdateOption
WithDryRun creates an option that runs the full verification pipeline (signature, checksum) but skips the final binary replacement step. Useful for testing.
func WithIgnoreDigest ¶ added in v0.0.17
func WithIgnoreDigest() UpdateOption
WithIgnoreDigest creates an option to ignore digest/checksum verification during update.
func WithIgnoreSignature ¶ added in v0.0.17
func WithIgnoreSignature() UpdateOption
WithIgnoreSignature creates an option to ignore signature verification during update.
type UpdatePolicy ¶ added in v0.0.17
type UpdatePolicy struct {
// contains filtered or unexported fields
}
func (*UpdatePolicy) Check ¶ added in v0.0.17
func (up *UpdatePolicy) Check() error
Click to show internal directories.
Click to hide internal directories.